@@ -40,18 +40,19 @@ class ThermalSurface(MultiComponentSurface):
         self.scale.extend([100.0])
         self.bounds.extend([[250.0, 400.0]])
         self.surf_temp_ind = len(self.statevec)-1
-        # Treat emissive surfaces as a fractional blackbody
         self.emissive = True
         self.n_state = len(self.init)
 
         # Value recommended by Glynn Hulley
         self.emissivity_for_surface_T_init = 0.98
         if "emissivity_for_surface_T_init" in config.keys():
-            self.emissivity_for_surface_T_init = config['emissivity_for_surface_T_init']
+            self.emissivity_for_surface_T_init = \
+                config['emissivity_for_surface_T_init']
 
         self.surface_T_prior_sigma_degK = 1.
         if "surface_T_prior_sigma_degK" in config.keys():
-            self.surface_T_prior_sigma_degK = config['surface_T_prior_sigma_degK']
+            self.surface_T_prior_sigma_degK = \
+                config['surface_T_prior_sigma_degK']
 
     def xa(self, x_surface, geom):
         """Mean of prior distribution, calculated at state x.  We find
@@ -66,31 +67,16 @@ class ThermalSurface(MultiComponentSurface):
         """Covariance of prior distribution, calculated at state x."""
 
         Cov = MultiComponentSurface.Sa(self, x_surface, geom)
-        Cov[self.surf_temp_ind, self.surf_temp_ind] = self.surface_T_prior_sigma_degK**2
+        Cov[self.surf_temp_ind, self.surf_temp_ind] = \
+            self.surface_T_prior_sigma_degK**2
 
         return Cov
 
-    def fit_params(self, rfl_meas, geom, meas, L_total_without_surface_emission, 
-                   trans_ground_to_sensor, clearest_indices):
-        """Given a reflectance estimate and one or more emissive parameters, 
-          fit a state vector."""
-
-        def err(z):
-            T = z
-            emissivity = self.emissivity_for_surface_T_init
-            Ls_est, d = emissive_radiance(emissivity, T, self.wl[clearest_indices])
-            resid = trans_ground_to_sensor[clearest_indices]*Ls_est + \
-                    L_total_without_surface_emission[clearest_indices] - \
-                    meas[clearest_indices]
-            return sum(resid**2)
+    def fit_params(self, rfl_meas, geom, *args):
+        """Given a reflectance estimate, find the surface reflectance"""
 
         x_surface = MultiComponentSurface.fit_params(self, rfl_meas, geom)
-
-        T = minimize(err, s.array([self.init[self.surf_temp_ind]])).x
-        T = max(self.bounds[self.surf_temp_ind][0]+eps,
-                min(T, self.bounds[self.surf_temp_ind][1]-eps))
-        x_surface[self.surf_temp_ind] = T
-        self.init[self.surf_temp_ind] = T  # Kind of hacky
+        x_surface[self.surf_temp_ind] = self.init[self.surf_temp_ind]
 
         return x_surface
 
@@ -138,7 +124,6 @@ class ThermalSurface(MultiComponentSurface):
         """Emission of surface, as a radiance."""
 
         T = x_surface[self.surf_temp_ind]
-        #emissivity = s.ones(self.n_wl, dtype=float)
         rfl = self.calc_rfl(x_surface, geom)
         rfl[rfl > 1.] = 1.
         emissivity = 1 - rfl
@@ -149,18 +134,11 @@ class ThermalSurface(MultiComponentSurface):
         """Partial derivative of surface emission with respect to state vector, 
         calculated at x_surface."""
 
-        # dLs_dsurface = MultiComponentSurface.dLs_dsurface(self, x_surface,
-        #                                                  geom)
         T = x_surface[self.surf_temp_ind]
         rfl = self.calc_rfl(x_surface, geom)
         emissivity = 1 - rfl
         Ls, dLs_dT = emissive_radiance(emissivity, T, self.wl)
         dLs_drfl = s.diag(-1*Ls)
-
-        #frac = x_surface[self.bb_frac_ind]
-        #emissivity = s.ones(self.n_wl, dtype=float)
-        # dLs_dsurface[:, self.surf_temp_ind] = dLs_dT *
-
         dLs_dsurface = s.vstack([dLs_drfl, dLs_dT]).T
 
         return dLs_dsurface
